/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: scene.h,v 1.8 2008/09/18 23:51:33 bowkenken Exp $
***************************************************************/

#ifndef	SCENE_H
#define	SCENE_H

/***************************************************************
* ڤؤ
***************************************************************/

/* μ */

typedef enum {
	SCENE_N_NULL,

	SCENE_N_INIT,
	SCENE_N_TITLE,
	SCENE_N_OPENING,

	SCENE_N_TOWN,
	SCENE_N_SHOP,

	SCENE_N_DUN,
	SCENE_N_BATTLE,
	SCENE_N_BATTLE_BOSS,

	SCENE_N_GAME_OVER,
	SCENE_N_GAME_OVER_WAIT,
	SCENE_N_GAME_OVER_END,

	SCENE_N_ENDING,
	SCENE_N_ENDING_EPILOGUE,
	SCENE_N_ENDING_SPACE,
	SCENE_N_ENDING_END,

	SCENE_N_SEL_MBR_GRAPH,

	SCENE_N_MAX_N,
} scene_n_t;

typedef enum {
	SCENE_GROUP_N_NULL,

	SCENE_GROUP_N_INIT,
	SCENE_GROUP_N_TITLE,

	SCENE_GROUP_N_PLAYING,
	SCENE_GROUP_N_BATTLE,

	SCENE_GROUP_N_GAME_OVER,
	SCENE_GROUP_N_ENDING,
	SCENE_GROUP_N_GAME_END,

	SCENE_GROUP_N_SEL_GRAPH,

	SCENE_GROUP_N_DEMO,

	SCENE_GROUP_N_CAN_SKIP,
	SCENE_GROUP_N_CAN_NOT_SKIP,

	SCENE_GROUP_N_MAX_N,
} scene_group_n_t;

#endif	/* SCENE_H */
